@@ -88,10 +88,13 @@ class Config(Command):
 
 
 class Setup(Command):
-    def __init__(self):
+    def __init__(self, host):
         """Constructor of Setup class
+
+        :param host: instance of :class:`Host`
         """
         super(Setup, self).__init__()
+        self._host = host
         self.after = None
         self._config = {}
 
@@ -101,10 +104,11 @@ class Setup(Command):
         :param filename: filename of config file (e.g. '/etc/nginx/nginx.conf')
         :returns: instance of :class:`Config`
         """
+        key = (self._host.name, filename)
         try:
-            config = self._config[filename]
+            config = self._config[key]
         except KeyError:
-            self._config[filename] = config = Config(filename)
+            self._config[key] = config = Config(filename)
         return config
 
     @property
@@ -116,16 +120,42 @@ class Setup(Command):
         return self._config
 
 
+class Host(object):
+    def __init__(self):
+        """Constructor of Host class
+        """
+        self.name = None
+        self.current_hostname = None
+
+    def __enter__(self):
+        self.name = self.current_hostname
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        self.name = None
+
+
 class Package(object):
-    def __init__(self, name=None):
+    def __init__(self, name=None, *args):
         """Constructor of Package class
 
         :param name: name of package (e.g. 'nginx'). If not given or None,
             name is takes from filename (e.g. If filename is 'foo.py', name is
             'foo').
+        :param args: name of related packages
+            (e.g. 'mysql' and 'mysql-clients')
         """
         if name is None:
             filename = inspect.currentframe().f_back.f_code.co_filename
             name = os.path.splitext(os.path.basename(filename))[0]
-        self.name = name
-        self.setup = Setup()
+        self.name = (name,) + args
+        self._host = Host()
+        self.setup = Setup(self._host)
+
+    def host(self, hostname):
+        """Set the one time hostname for context manager
+
+        :param hostname: string of target host or IP address
+        :returns: instance of :class:`Host`
+        """
+        self._host.current_hostname = hostname
+        return self._host
